Confirmation - Lending Club

This website does not support this version of Internet Explorer. Please upgrade to the latest version for a better experience. Upgrade Now
Lending Club
Utilities

- Welcome Jeremy!
- Account
- Profile
- Sign Out
- Help

# Confirmation

[ ? ]

### Congratulations

We have received your order for a total of $100 (4 Notes at an average interest rate of 16.92%)

### Here's what's next

- An order confirmation email is on its way.
- We will update you periodically until all Notes have been issued or canceled.
- For real-time updates, please visit your Account Summary.

### Assign these Notes to a portfolio

Track the Notes in this order in a new or an existing portfolio.

Assign to
New Portfolio

### Order Details #6954932 - 05/01/2013

Print your order confirmation

Loan ID | Title | Rate | Loan Amount | Invested
--- | --- | --- | --- | ---
4569134 | Credit Card refinance | C3 15.80% | $19,000 | $25
4796210 | Debt consolidation | C5 17.27% | $20,000 | $25
4776834 | burial exspenses | E3 21.49% | $4,700 | $25
4794709 | Eliminate Credit Card Debt | B4 13.11% | $17,000 | $25
Notes: 4 | Average Rate: 16.92% | Total: $100

Share The News
Congratulations on your investment. Spread the word - invite your friends to join Lending Club today.
orderedInvestor
tc_nvapp01